@@ -1,4 +1,4 @@
-/* ID: lad_LP.c, last updated 2022-10-17, F.Osorio */
+/* ID: lad_LP.c, last updated 2024-09-07, F.Osorio */
 
 #include "base.h"
 #include "interface.h"
@@ -18,14 +18,14 @@ lad_BR(double *y, double *x, int *nobs, int *vars, double *coef, double *scale,
   /* initialization */
   n2   = n + 2;
   p2   = p + 2;
-  z    = (double *) Calloc(n2 * p2, double);
-  work = (int *) Calloc(n, int);
+  z    = (double *) R_Calloc(n2 * p2, double);
+  work = (int *) R_Calloc(n, int);
   copy_mat(z, n2, x, n, n, p);
 
   /* call fitter */
   F77_CALL(l1br)(z, y, &n, &p, &n2, &p2, coef, residuals, &minimum,
                  iter, tolerance, rank, info, work);
-  Free(z); Free(work);
+  R_Free(z); R_Free(work);
 
   /* save results */
   *sad   = minimum;
